"use strict";

const Promise = require("bluebird");
const lodash = require("lodash");
const util = require("util");
const program = require("commander");
const Config = require("./utils/config");
const TextUI = require("./utils/textui");
const Myperf = require("./utils/myperf");
const logger = require("./utils/logger");
const constx = require("./utils/constx");
const ApiClient = require(constx.FRAMEWORK.NAMESPACE + "-api");
const SPECIAL_ARGS = ["package", "payload"];
module.exports = function (a = {}) {
  let b = a.adapter;
  let c = a.listener;
  let d;
  if (lodash.isObject(b)) {
    d = new TextUI();
  } else {
    const e = new Config(a);
    const f = e.getConfig();
    b = new ApiClient(lodash.extend(f, {
      logger: logger,
      ws: c
    }));
    const g = new Myperf();
    d = new TextUI({
      config: e,
      myperf: g
    });
  }
  b.on("started", function () {
    logger.debug(" The command is started");
  });
  b.on("progress", function (a) {
    logger.debug(" The command is processing");
  });
  b.on("completed", function (a) {
    d.displayCliOutput(a);
  });
  b.on("failed", function (a) {
    d.displayCliOutput(a);
  });
  b.on("done", function () {
    logger.debug(" - The command is done");
  });
  b.on("noop", function () {
    logger.debug(" - The command not found");
  });
  b.on("close", function (a, b) {
    logger.debug(" - The connection is closed (%s). Message: %s", a, b);
  });
  b.on("error", function (a) {
    logger.debug(" - The connection has been broken - %s", a);
    d.displayException(a);
  });
  const e = Promise.promisify(b.loadDefinition, {
    context: b
  });
  e().then(function (a) {
    let c = a && a.payload || {};
    return Promise.resolve().then(function () {
      d.displayCliHeader(c);
      return run(b, c);
    }).then(function () {
      d.displayCliFooter(c);
    });
  }).catch(function (a) {
    d.displayException(a);
  });
};
const run = function (a, b) {
  return Promise.promisify(function (c) {
    b = b || {};
    logger.trace(" * cli definition: %s", JSON.stringify(b, null, 2));
    const d = b.commands || [];
    for (let b = 0; b < d.length; b++) {
      const e = d[b];
      const f = [];
      let g = program.command(e.name).description(e.description);
      if (e.package) {
        g = g.option("--package [string]", "Package name");
        f.push("package");
      }
      const h = e.options || [];
      for (let a = 0; a < h.length; a++) {
        const b = h[a];
        g = g.option(util.format("-%s --%s %s", b.abbr, b.name, b.required ? "<value>" : "[value]"), b.description);
        f.push(b.name);
      }
      if (lodash.isObject(e.schema)) {
        g = g.option("--payload [json]", "Data (in JSON format)");
        f.push("payload");
      }
      g = g.action(function (b, d) {
        return function (e) {
          let f = {
            name: b.name,
            options: lodash.omit(lodash.pick(e, d), SPECIAL_ARGS)
          };
          if (d && d.indexOf("package") >= 0) {
            f["package"] = e["package"];
          }
          if (d && d.indexOf("payload") >= 0) {
            f["payload"] = JSON.parse(e["payload"]);
          }
          a.execCommand(f, c);
        };
      }(e, f));
    }
    program.parse(process.argv);
    if (process.argv.length <= 2) {
      program.outputHelp(function (a) {
        process.stdout.write(a);
        c();
      });
    }
  })();
};