"use strict";

const fs = require("fs");
const path = require("path");
function loadPackage() {
  return JSON.parse(fs.readFileSync(path.join(__dirname, "/../../package.json"), "utf8"));
}
function injectPackageInfo(a = {}) {
  const b = loadPackage();
  //
  Object.assign(a, {
    FRAMEWORK: {
      NAMESPACE: getFrameworkName(b.name),
      PACKAGE_NAME: b.name,
      VERSION: b.version
    }
  });
  //
  return a;
}
function getFrameworkName(a) {
  const b = [/^@(?<scope>.+)\/(?<name>[a-zA-Z]{1}[a-zA-Z0-9-_]*)$/, /^(?<scope>[a-zA-Z]+)-(?<name>[a-zA-Z]{1}[a-zA-Z0-9-_]*)$/];
  for (let c of b) {
    const b = a.match(c);
    if (b && b.groups) {
      const a = b.groups["scope"];
      if (isString(a)) {
        return a;
      }
    }
  }
  //
  return a;
}
function isString(a) {
  return typeof a === "string";
}
const CONSTANTS = {
  argumentSchema: {
    "type": "object",
    "oneOf": [{
      "properties": {
        "state": {
          "type": "string",
          "enum": ["completed", "failed"]
        },
        "message": {
          "type": "string"
        },
        "payload": {
          "type": "array",
          "items": {
            "oneOf": [{
              "properties": {
                "type": {
                  "type": "string",
                  "enum": ["json"]
                },
                "title": {
                  "type": "string"
                },
                "data": {
                  "type": ["boolean", "number", "string", "array", "object"]
                }
              },
              "required": ["type", "data"]
            }, {
              "properties": {
                "type": {
                  "type": "string",
                  "enum": ["record", "object"]
                },
                "title": {
                  "type": "string"
                },
                "label": {
                  "type": "object"
                },
                "data": {
                  "type": "object"
                }
              },
              "required": ["type", "label", "data"]
            }, {
              "properties": {
                "type": {
                  "type": "string",
                  "enum": ["table", "grid"]
                },
                "title": {
                  "type": "string"
                },
                "label": {
                  "type": "object"
                },
                "data": {
                  "type": "array",
                  "minItems": 1,
                  "items": {
                    "type": "object"
                  }
                }
              },
              "required": ["type", "label", "data"]
            }]
          }
        }
      }
    }]
  }
};
module.exports = injectPackageInfo(CONSTANTS);